def relu(input: Tensor,
    inplace: bool=False) -> Tensor:
  if inplace:
    result = torch.relu_(input)
  else:
    result = torch.relu(input)
  return result
def multi_head_attention_forward(query: Tensor,
    key: Tensor,
    value: Tensor,
    embed_dim_to_check: int,
    num_heads: int,
    in_proj_weight: Tensor,
    in_proj_bias: Optional[Tensor],
    bias_k: Optional[Tensor],
    bias_v: Optional[Tensor],
    add_zero_attn: bool,
    dropout_p: float,
    out_proj_weight: Tensor,
    out_proj_bias: Optional[Tensor],
    training: bool=True,
    key_padding_mask: Optional[Tensor]=None,
    need_weights: bool=True,
    attn_mask: Optional[Tensor]=None,
    use_separate_proj_weight: bool=False,
    q_proj_weight: Optional[Tensor]=None,
    k_proj_weight: Optional[Tensor]=None,
    v_proj_weight: Optional[Tensor]=None,
    static_k: Optional[Tensor]=None,
    static_v: Optional[Tensor]=None,
    average_attn_weights: bool=True) -> Tuple[Tensor, Optional[Tensor]]:
  _0 = __torch__.torch.nn.functional._mha_shape_check
  _1 = "was expecting embedding dimension of {}, but got {}"
  _2 = "embed_dim {} not divisible by num_heads {}"
  _3 = "key\'s sequence and batch dims {} do not match value\'s {}"
  _4 = "key shape {} does not match value shape {}"
  _5 = __torch__.torch.nn.functional._in_projection_packed
  _6 = "AssertionError: use_separate_proj_weight is True but q_proj_weight is None"
  _7 = "AssertionError: use_separate_proj_weight is True but k_proj_weight is None"
  _8 = "AssertionError: use_separate_proj_weight is True but v_proj_weight is None"
  _9 = __torch__.torch.nn.functional._in_projection
  _10 = "Byte tensor for attn_mask in nn.MultiheadAttention is deprecated. Use bool tensor instead."
  _11 = "Only float, byte, and bool types are supported for attn_mask, not {}"
  _12 = "The shape of the 2D attn_mask is {}, but should be {}."
  _13 = "The shape of the 3D attn_mask is {}, but should be {}."
  _14 = "attn_mask\'s dimension {} is not supported"
  _15 = "Byte tensor for key_padding_mask in nn.MultiheadAttention is deprecated. Use bool tensor instead."
  _16 = "AssertionError: bias cannot be added to static key."
  _17 = "AssertionError: bias cannot be added to static value."
  _18 = "expecting static_k.size(0) of {}, but got {}"
  _19 = "expecting static_k.size(2) of {}, but got {}"
  _20 = "expecting static_v.size(0) of {}, but got {}"
  _21 = "expecting static_v.size(2) of {}, but got {}"
  _22 = "expecting key_padding_mask shape of {}, but got {}"
  _23 = __torch__.torch.nn.functional._scaled_dot_product_attention
  _24 = uninitialized(Optional[Tensor])
  _25 = uninitialized(Optional[Tensor])
  _26 = uninitialized(Tensor)
  is_batched = _0(query, key, value, key_padding_mask, attn_mask, num_heads, )
  if torch.__not__(is_batched):
    query1 = torch.unsqueeze(query, 1)
    key1 = torch.unsqueeze(key, 1)
    value1 = torch.unsqueeze(value, 1)
    _27 = torch.__isnot__(key_padding_mask, None)
    if _27:
      key_padding_mask2 = unchecked_cast(Tensor, key_padding_mask)
      key_padding_mask3 = torch.unsqueeze(key_padding_mask2, 0)
      key_padding_mask1 : Optional[Tensor] = key_padding_mask3
    else:
      key_padding_mask1 = key_padding_mask
    query0, key0, value0, key_padding_mask0 = query1, key1, value1, key_padding_mask1
  else:
    query0, key0, value0, key_padding_mask0 = query, key, value, key_padding_mask
  tgt_len, bsz, embed_dim, = torch.size(query0)
  src_len, _28, _29, = torch.size(key0)
  _30 = torch.eq(embed_dim, embed_dim_to_check)
  if _30:
    pass
  else:
    _31 = torch.format(_1, embed_dim_to_check, embed_dim)
    ops.prim.RaiseException(torch.add("AssertionError: ", _31))
  embed_dim0 = unchecked_cast(int, embed_dim)
  head_dim = torch.floordiv(embed_dim0, num_heads)
  _32 = torch.eq(torch.mul(head_dim, num_heads), embed_dim0)
  if _32:
    pass
  else:
    _33 = torch.format(_2, embed_dim0, num_heads)
    ops.prim.RaiseException(torch.add("AssertionError: ", _33))
  if use_separate_proj_weight:
    _34 = torch.slice(torch.size(key0), None, 2)
    _35 = torch.slice(torch.size(value0), None, 2)
    if torch.eq(_34, _35):
      pass
    else:
      _36 = torch.slice(torch.size(key0), None, 2)
      _37 = torch.slice(torch.size(value0), None, 2)
      _38 = torch.add("AssertionError: ", torch.format(_3, _36, _37))
      ops.prim.RaiseException(_38)
  else:
    _39 = torch.eq(torch.size(key0), torch.size(value0))
    if _39:
      pass
    else:
      _40 = torch.format(_4, torch.size(key0), torch.size(value0))
      _41 = torch.add("AssertionError: ", _40)
      ops.prim.RaiseException(_41)
  _42 = torch.__not__(use_separate_proj_weight)
  if _42:
    _43 = _5(query0, key0, value0, in_proj_weight, in_proj_bias, )
    q0, k0, v0, = _43
    k, v, q = k0, v0, q0
  else:
    _44 = torch.__isnot__(q_proj_weight, None)
    if _44:
      q_proj_weight1 = unchecked_cast(Tensor, q_proj_weight)
      q_proj_weight0 = q_proj_weight1
    else:
      ops.prim.RaiseException(_6)
      q_proj_weight0 = _26
    _45 = torch.__isnot__(k_proj_weight, None)
    if _45:
      k_proj_weight1 = unchecked_cast(Tensor, k_proj_weight)
      k_proj_weight0 = k_proj_weight1
    else:
      ops.prim.RaiseException(_7)
      k_proj_weight0 = _26
    _46 = torch.__isnot__(v_proj_weight, None)
    if _46:
      v_proj_weight1 = unchecked_cast(Tensor, v_proj_weight)
      v_proj_weight0 = v_proj_weight1
    else:
      ops.prim.RaiseException(_8)
      v_proj_weight0 = _26
    if torch.__is__(in_proj_bias, None):
      b_q, b_k, b_v = None, None, None
    else:
      in_proj_bias0 = unchecked_cast(Tensor, in_proj_bias)
      b_q0, b_k0, b_v0, = torch.chunk(in_proj_bias0, 3)
      b_q, b_k, b_v = b_q0, b_k0, b_v0
    _47 = _9(query0, key0, value0, q_proj_weight0, k_proj_weight0, v_proj_weight0, b_q, b_k, b_v, )
    q1, k1, v1, = _47
    k, v, q = k1, v1, q1
  if torch.__isnot__(attn_mask, None):
    attn_mask1 = unchecked_cast(Tensor, attn_mask)
    _48 = torch.eq(ops.prim.dtype(attn_mask1), 0)
    if _48:
      torch.warn(_10)
      attn_mask2 = torch.to(attn_mask1, 11)
    else:
      _49 = torch.is_floating_point(attn_mask1)
      if _49:
        _50 = True
      else:
        _51 = torch.eq(ops.prim.dtype(attn_mask1), 11)
        _50 = _51
      if _50:
        pass
      else:
        _52 = torch.format(_11, ops.prim.dtype(attn_mask1))
        _53 = torch.add("AssertionError: ", _52)
        ops.prim.RaiseException(_53)
      attn_mask2 = attn_mask1
    if torch.eq(torch.dim(attn_mask2), 2):
      correct_2d_size = (tgt_len, src_len)
      _54 = torch.ne(torch.size(attn_mask2), [tgt_len, src_len])
      if _54:
        _55 = torch.format(_12, torch.size(attn_mask2), correct_2d_size)
        ops.prim.RaiseException(_55)
      else:
        pass
      attn_mask3 = torch.unsqueeze(attn_mask2, 0)
    else:
      _56 = torch.eq(torch.dim(attn_mask2), 3)
      if _56:
        _57 = torch.mul(bsz, num_heads)
        correct_3d_size = (_57, tgt_len, src_len)
        _58 = torch.ne(torch.size(attn_mask2), [_57, tgt_len, src_len])
        if _58:
          _59 = torch.format(_13, torch.size(attn_mask2), correct_3d_size)
          ops.prim.RaiseException(_59)
        else:
          pass
      else:
        _60 = torch.format(_14, torch.dim(attn_mask2))
        ops.prim.RaiseException(_60)
      attn_mask3 = attn_mask2
    attn_mask0 : Optional[Tensor] = attn_mask3
  else:
    attn_mask0 = attn_mask
  _61 = torch.__isnot__(key_padding_mask0, None)
  if _61:
    key_padding_mask5 = unchecked_cast(Tensor, key_padding_mask0)
    _63 = torch.eq(ops.prim.dtype(key_padding_mask5), 0)
    _62, key_padding_mask4 = _63, key_padding_mask5
  else:
    _62, key_padding_mask4 = False, key_padding_mask0
  if _62:
    key_padding_mask7 = unchecked_cast(Tensor, key_padding_mask4)
    torch.warn(_15)
    key_padding_mask6 : Optional[Tensor] = torch.to(key_padding_mask7, 11)
  else:
    key_padding_mask6 = key_padding_mask4
  if torch.__isnot__(bias_k, None):
    bias_k1 = unchecked_cast(Tensor, bias_k)
    _64, bias_k0 = torch.__isnot__(bias_v, None), bias_k1
  else:
    _64, bias_k0 = False, bias_k
  if _64:
    bias_k2 = unchecked_cast(Tensor, bias_k0)
    bias_v0 = unchecked_cast(Tensor, bias_v)
    if torch.__is__(static_k, None):
      static_k1 : Optional[Tensor] = static_k
    else:
      ops.prim.RaiseException(_16)
      static_k1 = _25
    if torch.__is__(static_v, None):
      static_v1 : Optional[Tensor] = static_v
    else:
      ops.prim.RaiseException(_17)
      static_v1 = _24
    _65 = [k, torch.repeat(bias_k2, [1, bsz, 1])]
    k3 = torch.cat(_65)
    _66 = [v, torch.repeat(bias_v0, [1, bsz, 1])]
    v3 = torch.cat(_66)
    if torch.__isnot__(attn_mask0, None):
      attn_mask6 = unchecked_cast(Tensor, attn_mask0)
      attn_mask7 = __torch__.torch.nn.functional._pad(attn_mask6, [0, 1], "constant", 0., )
      attn_mask5 : Optional[Tensor] = attn_mask7
    else:
      attn_mask5 = attn_mask0
    _67 = torch.__isnot__(key_padding_mask6, None)
    if _67:
      key_padding_mask10 = unchecked_cast(Tensor, key_padding_mask6)
      key_padding_mask11 = __torch__.torch.nn.functional._pad(key_padding_mask10, [0, 1], "constant", 0., )
      key_padding_mask9 : Optional[Tensor] = key_padding_mask11
    else:
      key_padding_mask9 = key_padding_mask6
    static_k0, k2, static_v0, v2, attn_mask4, key_padding_mask8 = static_k1, k3, static_v1, v3, attn_mask5, key_padding_mask9
  else:
    if torch.__is__(bias_k0, None):
      pass
    else:
      ops.prim.RaiseException("AssertionError: ")
    if torch.__is__(bias_v, None):
      pass
    else:
      ops.prim.RaiseException("AssertionError: ")
    static_k0, k2, static_v0, v2, attn_mask4, key_padding_mask8 = static_k, k, static_v, v, attn_mask0, key_padding_mask6
  _68 = torch.contiguous(q)
  _69 = [tgt_len, torch.mul(bsz, num_heads), head_dim]
  q2 = torch.transpose(torch.view(_68, _69), 0, 1)
  if torch.__is__(static_k0, None):
    _70 = torch.contiguous(k2)
    _71 = [(torch.size(k2))[0], torch.mul(bsz, num_heads), head_dim]
    k5 = torch.transpose(torch.view(_70, _71), 0, 1)
    k4 = k5
  else:
    static_k2 = unchecked_cast(Tensor, static_k0)
    _72 = torch.eq(torch.size(static_k2, 0), torch.mul(bsz, num_heads))
    if _72:
      pass
    else:
      _73 = torch.format(_18, torch.mul(bsz, num_heads), torch.size(static_k2, 0))
      _74 = torch.add("AssertionError: ", _73)
      ops.prim.RaiseException(_74)
    _75 = torch.eq(torch.size(static_k2, 2), head_dim)
    if _75:
      pass
    else:
      _76 = torch.format(_19, head_dim, torch.size(static_k2, 2))
      _77 = torch.add("AssertionError: ", _76)
      ops.prim.RaiseException(_77)
    k4 = static_k2
  if torch.__is__(static_v0, None):
    _78 = torch.contiguous(v2)
    _79 = [(torch.size(v2))[0], torch.mul(bsz, num_heads), head_dim]
    v5 = torch.transpose(torch.view(_78, _79), 0, 1)
    v4 = v5
  else:
    static_v2 = unchecked_cast(Tensor, static_v0)
    _80 = torch.eq(torch.size(static_v2, 0), torch.mul(bsz, num_heads))
    if _80:
      pass
    else:
      _81 = torch.format(_20, torch.mul(bsz, num_heads), torch.size(static_v2, 0))
      _82 = torch.add("AssertionError: ", _81)
      ops.prim.RaiseException(_82)
    _83 = torch.eq(torch.size(static_v2, 2), head_dim)
    if _83:
      pass
    else:
      _84 = torch.format(_21, head_dim, torch.size(static_v2, 2))
      _85 = torch.add("AssertionError: ", _84)
      ops.prim.RaiseException(_85)
    v4 = static_v2
  if add_zero_attn:
    _86 = torch.mul(bsz, num_heads)
    _87 = ops.prim.dtype(k4)
    _88 = ops.prim.device(k4)
    _89 = torch.zeros([_86, 1, head_dim], dtype=_87, layout=None, device=_88)
    k7 = torch.cat([k4, _89], 1)
    _90 = ops.prim.dtype(v4)
    _91 = ops.prim.device(v4)
    _92 = torch.zeros([_86, 1, head_dim], dtype=_90, layout=None, device=_91)
    v7 = torch.cat([v4, _92], 1)
    if torch.__isnot__(attn_mask4, None):
      attn_mask10 = unchecked_cast(Tensor, attn_mask4)
      attn_mask11 = __torch__.torch.nn.functional._pad(attn_mask10, [0, 1], "constant", 0., )
      attn_mask9 : Optional[Tensor] = attn_mask11
    else:
      attn_mask9 = attn_mask4
    _93 = torch.__isnot__(key_padding_mask8, None)
    if _93:
      key_padding_mask14 = unchecked_cast(Tensor, key_padding_mask8)
      key_padding_mask15 = __torch__.torch.nn.functional._pad(key_padding_mask14, [0, 1], "constant", 0., )
      key_padding_mask13 : Optional[Tensor] = key_padding_mask15
    else:
      key_padding_mask13 = key_padding_mask8
    k6, key_padding_mask12, attn_mask8, v6 = k7, key_padding_mask13, attn_mask9, v7
  else:
    k6, key_padding_mask12, attn_mask8, v6 = k4, key_padding_mask8, attn_mask4, v4
  src_len0 = torch.size(k6, 1)
  _94 = torch.__isnot__(key_padding_mask12, None)
  if _94:
    key_padding_mask16 = unchecked_cast(Tensor, key_padding_mask12)
    _95 = torch.eq(torch.size(key_padding_mask16), [bsz, src_len0])
    if _95:
      pass
    else:
      _96 = torch.format(_22, (bsz, src_len0), torch.size(key_padding_mask16))
      _97 = torch.add("AssertionError: ", _96)
      ops.prim.RaiseException(_97)
    _98 = torch.view(key_padding_mask16, [bsz, 1, 1, src_len0])
    _99 = torch.expand(_98, [-1, num_heads, -1, -1])
    _100 = [torch.mul(bsz, num_heads), 1, src_len0]
    key_padding_mask17 = torch.reshape(_99, _100)
    if torch.__is__(attn_mask8, None):
      attn_mask13 = key_padding_mask17
    else:
      attn_mask14 = unchecked_cast(Tensor, attn_mask8)
      _101 = torch.eq(ops.prim.dtype(attn_mask14), 11)
      if _101:
        attn_mask16 = torch.logical_or(attn_mask14, key_padding_mask17)
        attn_mask15 = attn_mask16
      else:
        attn_mask17 = torch.masked_fill(attn_mask14, key_padding_mask17, -inf)
        attn_mask15 = attn_mask17
      attn_mask13 = attn_mask15
    attn_mask12 : Optional[Tensor] = attn_mask13
  else:
    attn_mask12 = attn_mask8
  if torch.__isnot__(attn_mask12, None):
    attn_mask19 = unchecked_cast(Tensor, attn_mask12)
    _103 = torch.eq(ops.prim.dtype(attn_mask19), 11)
    _102, attn_mask18 = _103, attn_mask19
  else:
    _102, attn_mask18 = False, attn_mask12
  if _102:
    attn_mask21 = unchecked_cast(Tensor, attn_mask18)
    new_attn_mask = torch.zeros_like(attn_mask21, dtype=ops.prim.dtype(q2))
    _104 = torch.masked_fill_(new_attn_mask, attn_mask21, -inf)
    attn_mask20 : Optional[Tensor] = new_attn_mask
  else:
    attn_mask20 = attn_mask18
  if torch.__not__(training):
    dropout_p0 = 0.
  else:
    dropout_p0 = dropout_p
  _105 = _23(q2, k6, v6, attn_mask20, dropout_p0, )
  attn_output, attn_output_weights, = _105
  _106 = torch.contiguous(torch.transpose(attn_output, 0, 1))
  attn_output0 = torch.view(_106, [tgt_len, bsz, embed_dim0])
  attn_output1 = torch.linear(attn_output0, out_proj_weight, out_proj_bias)
  if need_weights:
    attn_output_weights0 = torch.view(attn_output_weights, [bsz, num_heads, tgt_len, src_len0])
    if average_attn_weights:
      _108 = torch.sum(attn_output_weights0, [1])
      attn_output_weights1 = torch.div(_108, num_heads)
    else:
      attn_output_weights1 = attn_output_weights0
    if torch.__not__(is_batched):
      attn_output3 = torch.squeeze(attn_output1, 1)
      attn_output_weights3 = torch.squeeze(attn_output_weights1, 0)
      attn_output2, attn_output_weights2 = attn_output3, attn_output_weights3
    else:
      attn_output2, attn_output_weights2 = attn_output1, attn_output_weights1
    _109 = (attn_output2, attn_output_weights2)
    _107 = _109
  else:
    if torch.__not__(is_batched):
      attn_output4 = torch.squeeze(attn_output1, 1)
    else:
      attn_output4 = attn_output1
    _107 = (attn_output4, None)
  return _107
def dropout(input: Tensor,
    p: float=0.5,
    training: bool=True,
    inplace: bool=False) -> Tensor:
  _110 = "dropout probability has to be between 0 and 1, but got {}"
  if torch.lt(p, 0.):
    _111 = True
  else:
    _111 = torch.gt(p, 1.)
  if _111:
    ops.prim.RaiseException(torch.format(_110, p))
  else:
    pass
  if inplace:
    _112 = torch.dropout_(input, p, training)
  else:
    _112 = torch.dropout(input, p, training)
  return _112
def layer_norm(input: Tensor,
    normalized_shape: List[int],
    weight: Optional[Tensor]=None,
    bias: Optional[Tensor]=None,
    eps: float=1.0000000000000001e-05) -> Tensor:
  _113 = torch.layer_norm(input, normalized_shape, weight, bias, eps)
  return _113
def _mha_shape_check(query: Tensor,
    key: Tensor,
    value: Tensor,
    key_padding_mask: Optional[Tensor],
    attn_mask: Optional[Tensor],
    num_heads: int) -> bool:
  _114 = "For batched (3-D) `query`, expected `key` and `value` to be 3-D but found {}-D and {}-D tensors respectively"
  _115 = "For batched (3-D) `query`, expected `key_padding_mask` to be `None` or 2-D but found {}-D tensor instead"
  _116 = "For batched (3-D) `query`, expected `attn_mask` to be `None`, 2-D or 3-D but found {}-D tensor instead"
  _117 = "For unbatched (2-D) `query`, expected `key` and `value` to be 2-D but found {}-D and {}-D tensors respectively"
  _118 = "For unbatched (2-D) `query`, expected `key_padding_mask` to be `None` or 1-D but found {}-D tensor instead"
  _119 = "For unbatched (2-D) `query`, expected `attn_mask` to be `None`, 2-D or 3-D but found {}-D tensor instead"
  _120 = "Expected `attn_mask` shape to be {} but got {}"
  _121 = "query should be unbatched 2D or batched 3D tensor but received {}-D query tensor"
  _122 = uninitialized(bool)
  if torch.eq(torch.dim(query), 3):
    if torch.eq(torch.dim(key), 3):
      _123 = torch.eq(torch.dim(value), 3)
    else:
      _123 = False
    if _123:
      pass
    else:
      _124 = torch.format(_114, torch.dim(key), torch.dim(value))
      _125 = torch.add("AssertionError: ", _124)
      ops.prim.RaiseException(_125)
    _126 = torch.__isnot__(key_padding_mask, None)
    if _126:
      key_padding_mask18 = unchecked_cast(Tensor, key_padding_mask)
      _127 = torch.eq(torch.dim(key_padding_mask18), 2)
      if _127:
        pass
      else:
        _128 = torch.format(_115, torch.dim(key_padding_mask18))
        _129 = torch.add("AssertionError: ", _128)
        ops.prim.RaiseException(_129)
    else:
      pass
    if torch.__isnot__(attn_mask, None):
      attn_mask22 = unchecked_cast(Tensor, attn_mask)
      _130 = torch.dim(attn_mask22)
      if torch.__contains__([2, 3], _130):
        pass
      else:
        _131 = torch.format(_116, torch.dim(attn_mask22))
        _132 = torch.add("AssertionError: ", _131)
        ops.prim.RaiseException(_132)
    else:
      pass
    is_batched = True
  else:
    if torch.eq(torch.dim(query), 2):
      if torch.eq(torch.dim(key), 2):
        _133 = torch.eq(torch.dim(value), 2)
      else:
        _133 = False
      if _133:
        pass
      else:
        _134 = torch.format(_117, torch.dim(key), torch.dim(value))
        _135 = torch.add("AssertionError: ", _134)
        ops.prim.RaiseException(_135)
      _136 = torch.__isnot__(key_padding_mask, None)
      if _136:
        key_padding_mask19 = unchecked_cast(Tensor, key_padding_mask)
        _137 = torch.eq(torch.dim(key_padding_mask19), 1)
        if _137:
          pass
        else:
          _138 = torch.format(_118, torch.dim(key_padding_mask19))
          _139 = torch.add("AssertionError: ", _138)
          ops.prim.RaiseException(_139)
      else:
        pass
      if torch.__isnot__(attn_mask, None):
        attn_mask23 = unchecked_cast(Tensor, attn_mask)
        _140 = torch.dim(attn_mask23)
        _141 = torch.__contains__([2, 3], _140)
        if _141:
          pass
        else:
          _142 = torch.format(_119, torch.dim(attn_mask23))
          _143 = torch.add("AssertionError: ", _142)
          ops.prim.RaiseException(_143)
        _144 = torch.eq(torch.dim(attn_mask23), 3)
        if _144:
          _145 = (torch.size(query))[0]
          _146 = (torch.size(key))[0]
          expected_shape = (num_heads, _145, _146)
          _147 = torch.eq(torch.size(attn_mask23), [num_heads, _145, _146])
          if _147:
            pass
          else:
            _148 = torch.format(_120, expected_shape, torch.size(attn_mask23))
            _149 = torch.add("AssertionError: ", _148)
            ops.prim.RaiseException(_149)
        else:
          pass
      else:
        pass
      is_batched0 = False
    else:
      _150 = torch.format(_121, torch.dim(query))
      _151 = torch.add("AssertionError: ", _150)
      ops.prim.RaiseException(_151)
      is_batched0 = _122
    is_batched = is_batched0
  return is_batched
def _in_projection_packed(q: Tensor,
    k: Tensor,
    v: Tensor,
    w: Tensor,
    b: Optional[Tensor]=None) -> List[Tensor]:
  E = torch.size(q, -1)
  if torch.__is__(k, v):
    if torch.__is__(q, k):
      _154 = torch.chunk(torch.linear(q, w, b), 3, -1)
      _153 = _154
    else:
      _155 = torch.split(w, [E, torch.mul(E, 2)])
      w_q, w_kv, = _155
      if torch.__is__(b, None):
        b_q, b_kv = None, None
      else:
        b0 = unchecked_cast(Tensor, b)
        _156 = torch.split(b0, [E, torch.mul(E, 2)])
        b_q1, b_kv0, = _156
        b_q, b_kv = b_q1, b_kv0
      _157 = torch.linear(q, w_q, b_q)
      _158 = torch.chunk(torch.linear(k, w_kv, b_kv), 2, -1)
      _153 = torch.add([_157], _158)
    _152 = _153
  else:
    w_q0, w_k, w_v, = torch.chunk(w, 3)
    if torch.__is__(b, None):
      b_q2, b_k, b_v = None, None, None
    else:
      b1 = unchecked_cast(Tensor, b)
      b_q3, b_k1, b_v1, = torch.chunk(b1, 3)
      b_q2, b_k, b_v = b_q3, b_k1, b_v1
    _159 = [torch.linear(q, w_q0, b_q2), torch.linear(k, w_k, b_k), torch.linear(v, w_v, b_v)]
    _152 = _159
  return _152
def _in_projection(q: Tensor,
    k: Tensor,
    v: Tensor,
    w_q: Tensor,
    w_k: Tensor,
    w_v: Tensor,
    b_q: Optional[Tensor]=None,
    b_k: Optional[Tensor]=None,
    b_v: Optional[Tensor]=None) -> Tuple[Tensor, Tensor, Tensor]:
  _160 = "expecting query weights shape of {}, but got {}"
  _161 = "expecting key weights shape of {}, but got {}"
  _162 = "expecting value weights shape of {}, but got {}"
  _163 = "expecting query bias shape of {}, but got {}"
  _164 = "expecting key bias shape of {}, but got {}"
  _165 = "expecting value bias shape of {}, but got {}"
  _166 = uninitialized(Optional[Tensor])
  _167 = uninitialized(Optional[Tensor])
  _168 = uninitialized(Optional[Tensor])
  Eq = torch.size(q, -1)
  Ek = torch.size(k, -1)
  Ev = torch.size(v, -1)
  if torch.eq(torch.size(w_q), [Eq, Eq]):
    pass
  else:
    _169 = torch.format(_160, (Eq, Eq), torch.size(w_q))
    ops.prim.RaiseException(torch.add("AssertionError: ", _169))
  if torch.eq(torch.size(w_k), [Eq, Ek]):
    pass
  else:
    _170 = torch.format(_161, (Eq, Ek), torch.size(w_k))
    ops.prim.RaiseException(torch.add("AssertionError: ", _170))
  if torch.eq(torch.size(w_v), [Eq, Ev]):
    pass
  else:
    _171 = torch.format(_162, (Eq, Ev), torch.size(w_v))
    ops.prim.RaiseException(torch.add("AssertionError: ", _171))
  if torch.__is__(b_q, None):
    _172, b_q4 = True, b_q
  else:
    b_q5 = unchecked_cast(Tensor, b_q)
    _172, b_q4 = torch.eq(torch.size(b_q5), [Eq]), b_q5
  if _172:
    b_q6 : Optional[Tensor] = b_q4
  else:
    b_q7 = unchecked_cast(Tensor, b_q4)
    _173 = torch.format(_163, (Eq,), torch.size(b_q7))
    ops.prim.RaiseException(torch.add("AssertionError: ", _173))
    b_q6 = _168
  if torch.__is__(b_k, None):
    _174, b_k2 = True, b_k
  else:
    b_k3 = unchecked_cast(Tensor, b_k)
    _174, b_k2 = torch.eq(torch.size(b_k3), [Eq]), b_k3
  if _174:
    b_k4 : Optional[Tensor] = b_k2
  else:
    b_k5 = unchecked_cast(Tensor, b_k2)
    _175 = torch.format(_164, (Eq,), torch.size(b_k5))
    ops.prim.RaiseException(torch.add("AssertionError: ", _175))
    b_k4 = _167
  if torch.__is__(b_v, None):
    _176, b_v2 = True, b_v
  else:
    b_v3 = unchecked_cast(Tensor, b_v)
    _176, b_v2 = torch.eq(torch.size(b_v3), [Eq]), b_v3
  if _176:
    b_v4 : Optional[Tensor] = b_v2
  else:
    b_v5 = unchecked_cast(Tensor, b_v2)
    _177 = torch.format(_165, (Eq,), torch.size(b_v5))
    ops.prim.RaiseException(torch.add("AssertionError: ", _177))
    b_v4 = _166
  _178 = (torch.linear(q, w_q, b_q6), torch.linear(k, w_k, b_k4), torch.linear(v, w_v, b_v4))
  return _178
def _pad(input: Tensor,
    pad: List[int],
    mode: str="constant",
    value: float=0.) -> Tensor:
  _179 = "AssertionError: Padding length must be divisible by 2"
  _180 = "AssertionError: Padding length too large"
  _181 = "Padding mode \"{}\"\" doesn\'t take in value argument"
  _182 = __torch__.torch.nn.functional._pad_circular
  _183 = "Only 2D, 3D, 4D, 5D padding with non-constant padding are supported for now"
  _184 = uninitialized(Tensor)
  _185 = torch.eq(torch.remainder(torch.len(pad), 2), 0)
  if _185:
    pass
  else:
    ops.prim.RaiseException(_179)
  _186 = torch.le(torch.floordiv(torch.len(pad), 2), torch.dim(input))
  if _186:
    pass
  else:
    ops.prim.RaiseException(_180)
  if torch.eq(mode, "constant"):
    _188 = torch.constant_pad_nd(input, pad, value)
    _187 = _188
  else:
    if torch.eq(value, 0.):
      pass
    else:
      _189 = torch.add("AssertionError: ", torch.format(_181, mode))
      ops.prim.RaiseException(_189)
    if torch.eq(torch.len(pad), 2):
      if torch.eq(torch.dim(input), 2):
        _191 = True
      else:
        _191 = torch.eq(torch.dim(input), 3)
      _190 = _191
    else:
      _190 = False
    if _190:
      if torch.eq(mode, "reflect"):
        _194 = torch.reflection_pad1d(input, pad)
        _193 = _194
      else:
        if torch.eq(mode, "replicate"):
          _196 = torch.replication_pad1d(input, pad)
          _195 = _196
        else:
          if torch.eq(mode, "circular"):
            _197 = _182(input, pad, )
          else:
            ops.prim.RaiseException("")
            _197 = _184
          _195 = _197
        _193 = _195
      _192 = _193
    else:
      if torch.eq(torch.len(pad), 4):
        if torch.eq(torch.dim(input), 3):
          _199 = True
        else:
          _199 = torch.eq(torch.dim(input), 4)
        _198 = _199
      else:
        _198 = False
      if _198:
        if torch.eq(mode, "reflect"):
          _202 = torch.reflection_pad2d(input, pad)
          _201 = _202
        else:
          if torch.eq(mode, "replicate"):
            _204 = torch.replication_pad2d(input, pad)
            _203 = _204
          else:
            if torch.eq(mode, "circular"):
              _205 = _182(input, pad, )
            else:
              ops.prim.RaiseException("")
              _205 = _184
            _203 = _205
          _201 = _203
        _200 = _201
      else:
        if torch.eq(torch.len(pad), 6):
          if torch.eq(torch.dim(input), 4):
            _207 = True
          else:
            _208 = torch.eq(torch.dim(input), 5)
            _207 = _208
          _206 = _207
        else:
          _206 = False
        if _206:
          if torch.eq(mode, "reflect"):
            _211 = torch.reflection_pad3d(input, pad)
            _210 = _211
          else:
            if torch.eq(mode, "replicate"):
              _213 = torch.replication_pad3d(input, pad)
              _212 = _213
            else:
              _214 = torch.eq(mode, "circular")
              if _214:
                _215 = _182(input, pad, )
              else:
                ops.prim.RaiseException("")
                _215 = _184
              _212 = _215
            _210 = _212
          _209 = _210
        else:
          ops.prim.RaiseException(_183)
          _209 = _184
        _200 = _209
      _192 = _200
    _187 = _192
  return _187
def _scaled_dot_product_attention(q: Tensor,
    k: Tensor,
    v: Tensor,
    attn_mask: Optional[Tensor]=None,
    dropout_p: float=0.) -> Tuple[Tensor, Tensor]:
  B, Nt, E, = torch.size(q)
  q3 = torch.div(q, torch.sqrt(E))
  attn = torch.bmm(q3, torch.transpose(k, -2, -1))
  if torch.__isnot__(attn_mask, None):
    attn_mask24 = unchecked_cast(Tensor, attn_mask)
    attn0 = torch.add_(attn, attn_mask24)
  else:
    attn0 = attn
  attn1 = __torch__.torch.nn.functional.softmax(attn0, -1, 3, None, )
  if torch.gt(dropout_p, 0.):
    attn3 = __torch__.torch.nn.functional.dropout(attn1, dropout_p, True, False, )
    attn2 = attn3
  else:
    attn2 = attn1
  output = torch.bmm(attn2, v)
  return (output, attn2)
def _pad_circular(input: Tensor,
    padding: List[int]) -> Tensor:
  _216 = "AssertionError: Padding value causes wrapping around more than once."
  _217 = "AssertionError: Negative padding value is resulting in an empty dimension."
  in_shape = torch.size(input)
  paddable_shape = torch.slice(in_shape, 2)
  ndim = torch.len(paddable_shape)
  _218 = [9223372036854775807, torch.len(paddable_shape)]
  for idx in range(ops.prim.min(_218)):
    size = paddable_shape[idx]
    _219 = torch.neg(torch.add(torch.mul(idx, 2), 1))
    if torch.le(padding[_219], size):
      pass
    else:
      ops.prim.RaiseException(_216)
    _220 = torch.neg(torch.add(torch.mul(idx, 2), 2))
    if torch.le(padding[_220], size):
      pass
    else:
      ops.prim.RaiseException(_216)
    _221 = torch.neg(torch.add(torch.mul(idx, 2), 1))
    _222 = padding[_221]
    _223 = torch.neg(torch.add(torch.mul(idx, 2), 2))
    _224 = torch.add(torch.add(_222, padding[_223]), size)
    if torch.ge(_224, 0):
      pass
    else:
      ops.prim.RaiseException(_217)
  out_shape = torch.slice(in_shape, None, 2)
  _225 = [9223372036854775807, torch.len(paddable_shape)]
  out_shape0 = out_shape
  for idx0 in range(ops.prim.min(_225)):
    size0 = paddable_shape[idx0]
    _226 = torch.neg(torch.add(torch.mul(idx0, 2), 1))
    _227 = torch.add(size0, padding[_226])
    _228 = torch.neg(torch.add(torch.mul(idx0, 2), 2))
    out_shape1 = torch.add_(out_shape0, [torch.add(_227, padding[_228])])
    out_shape0 = out_shape1
  out = torch.new_empty(input, out_shape0)
  if torch.eq(ndim, 1):
    out_d0 = ops.prim.max(padding[-2], 0)
    out_d1 = torch.sub(out_shape0[2], ops.prim.max(padding[-1], 0))
    in_d0 = ops.prim.max(torch.neg(padding[-2]), 0)
    _229 = in_shape[2]
    _230 = ops.prim.max(torch.neg(padding[-1]), 0)
    in_d1 = torch.sub(_229, _230)
    _231 = torch.slice(input, -1, in_d0, in_d1)
    _232 = torch.slice(out, -1, out_d0, out_d1)
    _233 = torch.copy_(_232, _231)
  else:
    if torch.eq(ndim, 2):
      out_d00 = ops.prim.max(padding[-2], 0)
      out_d10 = torch.sub(out_shape0[2], ops.prim.max(padding[-1], 0))
      out_h0 = ops.prim.max(padding[-4], 0)
      out_h1 = torch.sub(out_shape0[3], ops.prim.max(padding[-3], 0))
      in_d00 = ops.prim.max(torch.neg(padding[-2]), 0)
      _234 = in_shape[2]
      _235 = ops.prim.max(torch.neg(padding[-1]), 0)
      in_d10 = torch.sub(_234, _235)
      in_h0 = ops.prim.max(torch.neg(padding[-4]), 0)
      _236 = in_shape[3]
      _237 = ops.prim.max(torch.neg(padding[-3]), 0)
      in_h1 = torch.sub(_236, _237)
      _238 = torch.slice(input, -2, in_d00, in_d10)
      _239 = torch.slice(_238, -1, in_h0, in_h1)
      _240 = torch.slice(out, -2, out_d00, out_d10)
      _241 = torch.slice(_240, -1, out_h0, out_h1)
      _242 = torch.copy_(_241, _239)
    else:
      if torch.eq(ndim, 3):
        out_d01 = ops.prim.max(padding[-2], 0)
        out_d11 = torch.sub(out_shape0[2], ops.prim.max(padding[-1], 0))
        out_h00 = ops.prim.max(padding[-4], 0)
        out_h10 = torch.sub(out_shape0[3], ops.prim.max(padding[-3], 0))
        out_w0 = ops.prim.max(padding[-6], 0)
        out_w1 = torch.sub(out_shape0[4], ops.prim.max(padding[-5], 0))
        in_d01 = ops.prim.max(torch.neg(padding[-2]), 0)
        _243 = in_shape[2]
        _244 = ops.prim.max(torch.neg(padding[-1]), 0)
        in_d11 = torch.sub(_243, _244)
        in_h00 = ops.prim.max(torch.neg(padding[-4]), 0)
        _245 = in_shape[3]
        _246 = ops.prim.max(torch.neg(padding[-3]), 0)
        in_h10 = torch.sub(_245, _246)
        in_w0 = ops.prim.max(torch.neg(padding[-6]), 0)
        _247 = in_shape[4]
        _248 = ops.prim.max(torch.neg(padding[-5]), 0)
        in_w1 = torch.sub(_247, _248)
        _249 = torch.slice(input, -3, in_d01, in_d11)
        _250 = torch.slice(_249, -2, in_h00, in_h10)
        _251 = torch.slice(_250, -1, in_w0, in_w1)
        _252 = torch.slice(out, -3, out_d01, out_d11)
        _253 = torch.slice(_252, -2, out_h00, out_h10)
        _254 = torch.slice(_253, -1, out_w0, out_w1)
        _255 = torch.copy_(_254, _251)
      else:
        pass
  if torch.gt(padding[-2], 0):
    _256 = torch.sub(out_shape0[2], padding[-2])
    i0 = torch.sub(_256, ops.prim.max(padding[-1], 0))
    i1 = torch.sub(out_shape0[2], ops.prim.max(padding[-1], 0))
    o1 = padding[-2]
    _257 = torch.slice(torch.slice(torch.slice(out), 1), 2, i0, i1)
    _258 = torch.slice(torch.slice(torch.slice(out), 1), 2, 0, o1)
    _259 = torch.copy_(_258, _257)
  else:
    pass
  if torch.gt(padding[-1], 0):
    i00 = ops.prim.max(padding[-2], 0)
    i10 = torch.add(ops.prim.max(padding[-2], 0), padding[-1])
    o0 = torch.sub(out_shape0[2], padding[-1])
    o10 = out_shape0[2]
    _260 = torch.slice(torch.slice(torch.slice(out), 1), 2, i00, i10)
    _261 = torch.slice(torch.slice(torch.slice(out), 1), 2, o0, o10)
    _262 = torch.copy_(_261, _260)
  else:
    pass
  if torch.gt(torch.len(padding), 2):
    if torch.gt(padding[-4], 0):
      _263 = torch.sub(out_shape0[3], padding[-4])
      i01 = torch.sub(_263, ops.prim.max(padding[-3], 0))
      i11 = torch.sub(out_shape0[3], ops.prim.max(padding[-3], 0))
      o11 = padding[-4]
      _264 = torch.slice(torch.slice(torch.slice(out), 1), 2)
      _265 = torch.slice(_264, 3, i01, i11)
      _266 = torch.slice(torch.slice(torch.slice(out), 1), 2)
      _267 = torch.copy_(torch.slice(_266, 3, 0, o11), _265)
    else:
      pass
    if torch.gt(padding[-3], 0):
      i02 = ops.prim.max(padding[-4], 0)
      i12 = torch.add(ops.prim.max(padding[-4], 0), padding[-3])
      o00 = torch.sub(out_shape0[3], padding[-3])
      o12 = out_shape0[3]
      _268 = torch.slice(torch.slice(torch.slice(out), 1), 2)
      _269 = torch.slice(_268, 3, i02, i12)
      _270 = torch.slice(torch.slice(torch.slice(out), 1), 2)
      _271 = torch.copy_(torch.slice(_270, 3, o00, o12), _269)
    else:
      pass
  else:
    pass
  if torch.gt(torch.len(padding), 4):
    if torch.gt(padding[-6], 0):
      _272 = torch.sub(out_shape0[4], padding[-6])
      i03 = torch.sub(_272, ops.prim.max(padding[-5], 0))
      i13 = torch.sub(out_shape0[4], ops.prim.max(padding[-5], 0))
      o13 = padding[-6]
      _273 = torch.slice(torch.slice(torch.slice(out), 1), 2)
      _274 = torch.slice(torch.slice(_273, 3), 4, i03, i13)
      _275 = torch.slice(torch.slice(torch.slice(out), 1), 2)
      _276 = torch.slice(torch.slice(_275, 3), 4, 0, o13)
      _277 = torch.copy_(_276, _274)
    else:
      pass
    if torch.gt(padding[-5], 0):
      i04 = ops.prim.max(padding[-6], 0)
      i14 = torch.add(ops.prim.max(padding[-6], 0), padding[-5])
      o01 = torch.sub(out_shape0[4], padding[-5])
      o14 = out_shape0[4]
      _278 = torch.slice(torch.slice(torch.slice(out), 1), 2)
      _279 = torch.slice(torch.slice(_278, 3), 4, i04, i14)
      _280 = torch.slice(torch.slice(torch.slice(out), 1), 2)
      _281 = torch.slice(torch.slice(_280, 3), 4, o01, o14)
      _282 = torch.copy_(_281, _279)
    else:
      pass
  else:
    pass
  return out
def softmax(input: Tensor,
    dim: Optional[int]=None,
    _stacklevel: int=3,
    dtype: Optional[int]=None) -> Tensor:
  _283 = __torch__.torch.nn.functional._get_softmax_dim
  if torch.__is__(dim, None):
    dim1 = _283("softmax", torch.dim(input), _stacklevel, )
    dim0 = dim1
  else:
    dim0 = unchecked_cast(int, dim)
  if torch.__is__(dtype, None):
    ret = torch.softmax(input, dim0)
  else:
    dtype0 = unchecked_cast(int, dtype)
    ret = torch.softmax(input, dim0, dtype0)
  return ret
def _get_softmax_dim(name: str,
    ndim: int,
    stacklevel: int) -> int:
  _284 = "Implicit dimension choice for {} has been deprecated. Change the call to include dim=X as an argument."
  torch.warn(torch.format(_284, name), stacklevel)
  if torch.eq(ndim, 0):
    _285 = True
  else:
    _285 = torch.eq(ndim, 1)
  if _285:
    _286 = True
  else:
    _286 = torch.eq(ndim, 3)
  if _286:
    ret = 0
  else:
    ret = 1
  return ret
